summary refs log tree commit diff
diff options
context:
space:
mode:
authorOlivier Wilkinson (reivilibre) <oliverw@matrix.org>2023-02-17 11:05:58 +0000
committerOlivier Wilkinson (reivilibre) <oliverw@matrix.org>2023-03-16 11:45:14 +0000
commitac566f45f6369a9bd7f787ebddaf4526f00aac13 (patch)
tree2cb4a3453a87cf194a74dba080a3ea3df1f0e594
parentRefresh remote profiles that have been marked as stale, in order to fill the ... (diff)
downloadsynapse-ac566f45f6369a9bd7f787ebddaf4526f00aac13.tar.xz
Rename method to make obvious it only applies to local users
-rw-r--r--synapse/storage/databases/main/user_directory.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/synapse/storage/databases/main/user_directory.py b/synapse/storage/databases/main/user_directory.py
index 97f09b73dd..f2f618c8fd 100644
--- a/synapse/storage/databases/main/user_directory.py
+++ b/synapse/storage/databases/main/user_directory.py
@@ -91,7 +91,7 @@ class UserDirectoryBackgroundUpdateStore(StateDeltasStore):
         )
         self.db_pool.updates.register_background_update_handler(
             "populate_user_directory_process_users",
-            self._populate_user_directory_process_users,
+            self._populate_user_directory_process_local_users,
         )
         self.db_pool.updates.register_background_update_handler(
             "populate_user_directory_cleanup", self._populate_user_directory_cleanup
@@ -265,7 +265,7 @@ class UserDirectoryBackgroundUpdateStore(StateDeltasStore):
                 # Upsert a user_directory record for each remote user we see.
                 for user_id, profile in users_with_profile.items():
                     # Local users are processed separately in
                     # `_populate_user_directory_users`; there we can read from
                     # the `profiles` table to ensure we don't leak their per-room
                     # profiles. It also means we write local users to this table
                     # exactly once, rather than once for every room they're in.
@@ -336,7 +336,7 @@ class UserDirectoryBackgroundUpdateStore(StateDeltasStore):
 
         return processed_event_count
 
-    async def _populate_user_directory_process_users(
+    async def _populate_user_directory_process_local_users(
         self, progress: JsonDict, batch_size: int
     ) -> int:
         """
@@ -265,7 +265,7 @@ class UserDirectoryBackgroundUpdateStore(StateDeltasStore):
                 for user_id, profile in users_with_profile.items():
                     # Local users are processed separately in
-                    # `_populate_user_directory_users`; there we can read from
+                    # `_populate_user_directory_local_users`; there we can read from
                     # the `profiles` table to ensure we don't leak their per-room
                     # profiles. It also means we write local users to this table